# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cache_control import CacheControl
import pprint
import six


class CacheControlSettingsDash(object):
    @poscheck_model
    def __init__(self,
                 timeline_manifest=None,
                 template_manifest=None):
        # type: (CacheControl, CacheControl) -> None

        self._timeline_manifest = None
        self._template_manifest = None
        self.discriminator = None

        if timeline_manifest is not None:
            self.timeline_manifest = timeline_manifest
        if template_manifest is not None:
            self.template_manifest = template_manifest

    @property
    def openapi_types(self):
        types = {
            'timeline_manifest': 'CacheControl',
            'template_manifest': 'CacheControl'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'timeline_manifest': 'timelineManifest',
            'template_manifest': 'templateManifest'
        }
        return attributes

    @property
    def timeline_manifest(self):
        # type: () -> CacheControl
        """Gets the timeline_manifest of this CacheControlSettingsDash.

        Cache control settings for DASH Timeline manifest.

        :return: The timeline_manifest of this CacheControlSettingsDash.
        :rtype: CacheControl
        """
        return self._timeline_manifest

    @timeline_manifest.setter
    def timeline_manifest(self, timeline_manifest):
        # type: (CacheControl) -> None
        """Sets the timeline_manifest of this CacheControlSettingsDash.

        Cache control settings for DASH Timeline manifest.

        :param timeline_manifest: The timeline_manifest of this CacheControlSettingsDash.
        :type: CacheControl
        """

        if timeline_manifest is not None:
            if not isinstance(timeline_manifest, CacheControl):
                raise TypeError("Invalid type for `timeline_manifest`, type has to be `CacheControl`")

        self._timeline_manifest = timeline_manifest

    @property
    def template_manifest(self):
        # type: () -> CacheControl
        """Gets the template_manifest of this CacheControlSettingsDash.

        Cache control settings for DASH Template manifest.

        :return: The template_manifest of this CacheControlSettingsDash.
        :rtype: CacheControl
        """
        return self._template_manifest

    @template_manifest.setter
    def template_manifest(self, template_manifest):
        # type: (CacheControl) -> None
        """Sets the template_manifest of this CacheControlSettingsDash.

        Cache control settings for DASH Template manifest.

        :param template_manifest: The template_manifest of this CacheControlSettingsDash.
        :type: CacheControl
        """

        if template_manifest is not None:
            if not isinstance(template_manifest, CacheControl):
                raise TypeError("Invalid type for `template_manifest`, type has to be `CacheControl`")

        self._template_manifest = template_manifest

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheControlSettingsDash):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.padding_duration_unit import PaddingDurationUnit
import pprint
import six


class PaddingSequence(object):
    @poscheck_model
    def __init__(self,
                 duration=None,
                 unit=None):
        # type: (float, PaddingDurationUnit) -> None

        self._duration = None
        self._unit = None
        self.discriminator = None

        if duration is not None:
            self.duration = duration
        if unit is not None:
            self.unit = unit

    @property
    def openapi_types(self):
        types = {
            'duration': 'float',
            'unit': 'PaddingDurationUnit'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'duration': 'duration',
            'unit': 'unit'
        }
        return attributes

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this PaddingSequence.

        Duration of the padding sequence, given in the unit specified by the `unit` property. The maximum duration is 300 frames or 10 seconds. If the unit is `FRAMES`, this needs to be an integer value and will be interpreted based on the input frame rate of the main part of the ConcatenationInputStream that is used by your video output stream(s). `FRAMES` is not allowed if the encoding does not contain a video output stream. (required)

        :return: The duration of this PaddingSequence.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this PaddingSequence.

        Duration of the padding sequence, given in the unit specified by the `unit` property. The maximum duration is 300 frames or 10 seconds. If the unit is `FRAMES`, this needs to be an integer value and will be interpreted based on the input frame rate of the main part of the ConcatenationInputStream that is used by your video output stream(s). `FRAMES` is not allowed if the encoding does not contain a video output stream. (required)

        :param duration: The duration of this PaddingSequence.
        :type: float
        """

        if duration is not None:
            if duration is not None and duration <= 0:
                raise ValueError("Invalid value for `duration`, must be a value greater than `0`")
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def unit(self):
        # type: () -> PaddingDurationUnit
        """Gets the unit of this PaddingSequence.

        The unit of the `duration` property

        :return: The unit of this PaddingSequence.
        :rtype: PaddingDurationUnit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        # type: (PaddingDurationUnit) -> None
        """Sets the unit of this PaddingSequence.

        The unit of the `duration` property

        :param unit: The unit of this PaddingSequence.
        :type: PaddingDurationUnit
        """

        if unit is not None:
            if not isinstance(unit, PaddingDurationUnit):
                raise TypeError("Invalid type for `unit`, type has to be `PaddingDurationUnit`")

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaddingSequence):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.media_info_type_response import MediaInfoTypeResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class TypeApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TypeApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, manifest_id, media_id, **kwargs):
        # type: (string_types, string_types, dict) -> MediaInfoTypeResponse
        """HLS Media Type

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param media_id: Id of the video media.
        :type media_id: string_types, required
        :return: Media-type
        :rtype: MediaInfoTypeResponse
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/media/{media_id}/type',
            path_params={'manifest_id': manifest_id, 'media_id': media_id},
            type=MediaInfoTypeResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.basic_media_info import BasicMediaInfo
import pprint
import six


class VttMediaInfo(BasicMediaInfo):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 group_id=None,
                 language=None,
                 assoc_language=None,
                 name=None,
                 is_default=None,
                 autoselect=None,
                 characteristics=None,
                 vtt_url=None,
                 uri=None,
                 forced=None):
        # type: (string_types, string_types, string_types, string_types, string_types, bool, bool, list[string_types], string_types, string_types, bool) -> None
        super(VttMediaInfo, self).__init__(id_=id_, group_id=group_id, language=language, assoc_language=assoc_language, name=name, is_default=is_default, autoselect=autoselect, characteristics=characteristics)

        self._vtt_url = None
        self._uri = None
        self._forced = None
        self.discriminator = None

        if vtt_url is not None:
            self.vtt_url = vtt_url
        if uri is not None:
            self.uri = uri
        if forced is not None:
            self.forced = forced

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(VttMediaInfo, self), 'openapi_types'):
            types = getattr(super(VttMediaInfo, self), 'openapi_types')

        types.update({
            'vtt_url': 'string_types',
            'uri': 'string_types',
            'forced': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(VttMediaInfo, self), 'attribute_map'):
            attributes = getattr(super(VttMediaInfo, self), 'attribute_map')

        attributes.update({
            'vtt_url': 'vttUrl',
            'uri': 'uri',
            'forced': 'forced'
        })
        return attributes

    @property
    def vtt_url(self):
        # type: () -> string_types
        """Gets the vtt_url of this VttMediaInfo.

        The URL of the referenced VTT file (required)

        :return: The vtt_url of this VttMediaInfo.
        :rtype: string_types
        """
        return self._vtt_url

    @vtt_url.setter
    def vtt_url(self, vtt_url):
        # type: (string_types) -> None
        """Sets the vtt_url of this VttMediaInfo.

        The URL of the referenced VTT file (required)

        :param vtt_url: The vtt_url of this VttMediaInfo.
        :type: string_types
        """

        if vtt_url is not None:
            if not isinstance(vtt_url, string_types):
                raise TypeError("Invalid type for `vtt_url`, type has to be `string_types`")

        self._vtt_url = vtt_url

    @property
    def uri(self):
        # type: () -> string_types
        """Gets the uri of this VttMediaInfo.

        The URI of the Rendition (required)

        :return: The uri of this VttMediaInfo.
        :rtype: string_types
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (string_types) -> None
        """Sets the uri of this VttMediaInfo.

        The URI of the Rendition (required)

        :param uri: The uri of this VttMediaInfo.
        :type: string_types
        """

        if uri is not None:
            if not isinstance(uri, string_types):
                raise TypeError("Invalid type for `uri`, type has to be `string_types`")

        self._uri = uri

    @property
    def forced(self):
        # type: () -> bool
        """Gets the forced of this VttMediaInfo.

        A value of true indicates that the Rendition contains content which is considered essential to play.

        :return: The forced of this VttMediaInfo.
        :rtype: bool
        """
        return self._forced

    @forced.setter
    def forced(self, forced):
        # type: (bool) -> None
        """Sets the forced of this VttMediaInfo.

        A value of true indicates that the Rendition contains content which is considered essential to play.

        :param forced: The forced of this VttMediaInfo.
        :type: bool
        """

        if forced is not None:
            if not isinstance(forced, bool):
                raise TypeError("Invalid type for `forced`, type has to be `bool`")

        self._forced = forced

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(VttMediaInfo, self), "to_dict"):
            result = super(VttMediaInfo, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VttMediaInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.mp4_muxing import Mp4Muxing
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.mp4_muxing_list_query_params import Mp4MuxingListQueryParams


class Mp4Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Mp4Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.information = InformationApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.drm = DrmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, mp4_muxing, **kwargs):
        # type: (string_types, Mp4Muxing, dict) -> Mp4Muxing
        """Add MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param mp4_muxing: The progressive MP4 muxing to be created
        :type mp4_muxing: Mp4Muxing, required
        :return: MP4 muxing
        :rtype: Mp4Muxing
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/mp4',
            mp4_muxing,
            path_params={'encoding_id': encoding_id},
            type=Mp4Muxing,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing
        :type muxing_id: string_types, required
        :return: Id of the MP4 muxing
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> Mp4Muxing
        """MP4 muxing details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing
        :type muxing_id: string_types, required
        :return: MP4 muxing
        :rtype: Mp4Muxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=Mp4Muxing,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, Mp4MuxingListQueryParams, dict) -> Mp4Muxing
        """List MP4 muxings

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: Mp4MuxingListQueryParams
        :return: List of MP4 muxings
        :rtype: Mp4Muxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Mp4Muxing,
            **kwargs
        )



from bitmovin_api_sdk.encoding.infrastructure.oci.oci_api import OciApi
from bitmovin_api_sdk.encoding.infrastructure.oci.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.oci.oci_account_list_query_params import OciAccountListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.enhanced_watermark_filter import EnhancedWatermarkFilter
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.enhanced_watermark_filter_list_query_params import EnhancedWatermarkFilterListQueryParams


class EnhancedWatermarkApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EnhancedWatermarkApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, enhanced_watermark_filter, **kwargs):
        # type: (EnhancedWatermarkFilter, dict) -> EnhancedWatermarkFilter
        """Create Enhanced Watermark Filter

        :param enhanced_watermark_filter: The Enhanced Watermark Filter to be created. Only one horizontal and one vertical distance parameter is allowed, either top or bottom, and either left or right. See example body.
        :type enhanced_watermark_filter: EnhancedWatermarkFilter, required
        :return: Enhanced Watermark Filter details
        :rtype: EnhancedWatermarkFilter
        """

        return self.api_client.post(
            '/encoding/filters/enhanced-watermark',
            enhanced_watermark_filter,
            type=EnhancedWatermarkFilter,
            **kwargs
        )

    def delete(self, filter_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Enhanced Watermark Filter

        :param filter_id: Id of the enhanced Watermark Filter.
        :type filter_id: string_types, required
        :return: Id of the Enhanced Watermark Filter.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/filters/enhanced-watermark/{filter_id}',
            path_params={'filter_id': filter_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, filter_id, **kwargs):
        # type: (string_types, dict) -> EnhancedWatermarkFilter
        """Enhanced Watermark Filter Details

        :param filter_id: Id of the enhanced Watermark Filter.
        :type filter_id: string_types, required
        :return: Enhanced Watermark details
        :rtype: EnhancedWatermarkFilter
        """

        return self.api_client.get(
            '/encoding/filters/enhanced-watermark/{filter_id}',
            path_params={'filter_id': filter_id},
            type=EnhancedWatermarkFilter,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (EnhancedWatermarkFilterListQueryParams, dict) -> EnhancedWatermarkFilter
        """List Enhanced Watermark Filters

        :param query_params: Query parameters
        :type query_params: EnhancedWatermarkFilterListQueryParams
        :return: List of Enhanced Watermark Filters
        :rtype: EnhancedWatermarkFilter
        """

        return self.api_client.get(
            '/encoding/filters/enhanced-watermark',
            query_params=query_params,
            pagination_response=True,
            type=EnhancedWatermarkFilter,
            **kwargs
        )



from bitmovin_api_sdk.encoding.filters.enhanced_watermark.enhanced_watermark_api import EnhancedWatermarkApi
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.enhanced_watermark_filter_list_query_params import EnhancedWatermarkFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.live_standby_pool_status import LiveStandbyPoolStatus
import pprint
import six


class LiveStandbyPoolResponse(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 target_pool_size=None,
                 ready_encodings=None,
                 preparing_encodings=None,
                 error_encodings=None,
                 encoding_template_name=None,
                 pool_status=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, int, string_types, LiveStandbyPoolStatus) -> None
        super(LiveStandbyPoolResponse, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._target_pool_size = None
        self._ready_encodings = None
        self._preparing_encodings = None
        self._error_encodings = None
        self._encoding_template_name = None
        self._pool_status = None
        self.discriminator = None

        if target_pool_size is not None:
            self.target_pool_size = target_pool_size
        if ready_encodings is not None:
            self.ready_encodings = ready_encodings
        if preparing_encodings is not None:
            self.preparing_encodings = preparing_encodings
        if error_encodings is not None:
            self.error_encodings = error_encodings
        if encoding_template_name is not None:
            self.encoding_template_name = encoding_template_name
        if pool_status is not None:
            self.pool_status = pool_status

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(LiveStandbyPoolResponse, self), 'openapi_types'):
            types = getattr(super(LiveStandbyPoolResponse, self), 'openapi_types')

        types.update({
            'target_pool_size': 'int',
            'ready_encodings': 'int',
            'preparing_encodings': 'int',
            'error_encodings': 'int',
            'encoding_template_name': 'string_types',
            'pool_status': 'LiveStandbyPoolStatus'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(LiveStandbyPoolResponse, self), 'attribute_map'):
            attributes = getattr(super(LiveStandbyPoolResponse, self), 'attribute_map')

        attributes.update({
            'target_pool_size': 'targetPoolSize',
            'ready_encodings': 'readyEncodings',
            'preparing_encodings': 'preparingEncodings',
            'error_encodings': 'errorEncodings',
            'encoding_template_name': 'encodingTemplateName',
            'pool_status': 'poolStatus'
        })
        return attributes

    @property
    def target_pool_size(self):
        # type: () -> int
        """Gets the target_pool_size of this LiveStandbyPoolResponse.

        Number of instances to keep ready for streaming while the pool is running (required)

        :return: The target_pool_size of this LiveStandbyPoolResponse.
        :rtype: int
        """
        return self._target_pool_size

    @target_pool_size.setter
    def target_pool_size(self, target_pool_size):
        # type: (int) -> None
        """Sets the target_pool_size of this LiveStandbyPoolResponse.

        Number of instances to keep ready for streaming while the pool is running (required)

        :param target_pool_size: The target_pool_size of this LiveStandbyPoolResponse.
        :type: int
        """

        if target_pool_size is not None:
            if target_pool_size is not None and target_pool_size < 0:
                raise ValueError("Invalid value for `target_pool_size`, must be a value greater than or equal to `0`")
            if not isinstance(target_pool_size, int):
                raise TypeError("Invalid type for `target_pool_size`, type has to be `int`")

        self._target_pool_size = target_pool_size

    @property
    def ready_encodings(self):
        # type: () -> int
        """Gets the ready_encodings of this LiveStandbyPoolResponse.

        Number of instances currently in ready state in the pool

        :return: The ready_encodings of this LiveStandbyPoolResponse.
        :rtype: int
        """
        return self._ready_encodings

    @ready_encodings.setter
    def ready_encodings(self, ready_encodings):
        # type: (int) -> None
        """Sets the ready_encodings of this LiveStandbyPoolResponse.

        Number of instances currently in ready state in the pool

        :param ready_encodings: The ready_encodings of this LiveStandbyPoolResponse.
        :type: int
        """

        if ready_encodings is not None:
            if ready_encodings is not None and ready_encodings < 0:
                raise ValueError("Invalid value for `ready_encodings`, must be a value greater than or equal to `0`")
            if not isinstance(ready_encodings, int):
                raise TypeError("Invalid type for `ready_encodings`, type has to be `int`")

        self._ready_encodings = ready_encodings

    @property
    def preparing_encodings(self):
        # type: () -> int
        """Gets the preparing_encodings of this LiveStandbyPoolResponse.

        Number of instances currently being prepared in the pool

        :return: The preparing_encodings of this LiveStandbyPoolResponse.
        :rtype: int
        """
        return self._preparing_encodings

    @preparing_encodings.setter
    def preparing_encodings(self, preparing_encodings):
        # type: (int) -> None
        """Sets the preparing_encodings of this LiveStandbyPoolResponse.

        Number of instances currently being prepared in the pool

        :param preparing_encodings: The preparing_encodings of this LiveStandbyPoolResponse.
        :type: int
        """

        if preparing_encodings is not None:
            if preparing_encodings is not None and preparing_encodings < 0:
                raise ValueError("Invalid value for `preparing_encodings`, must be a value greater than or equal to `0`")
            if not isinstance(preparing_encodings, int):
                raise TypeError("Invalid type for `preparing_encodings`, type has to be `int`")

        self._preparing_encodings = preparing_encodings

    @property
    def error_encodings(self):
        # type: () -> int
        """Gets the error_encodings of this LiveStandbyPoolResponse.

        Number of instances currently in error state in the pool

        :return: The error_encodings of this LiveStandbyPoolResponse.
        :rtype: int
        """
        return self._error_encodings

    @error_encodings.setter
    def error_encodings(self, error_encodings):
        # type: (int) -> None
        """Sets the error_encodings of this LiveStandbyPoolResponse.

        Number of instances currently in error state in the pool

        :param error_encodings: The error_encodings of this LiveStandbyPoolResponse.
        :type: int
        """

        if error_encodings is not None:
            if error_encodings is not None and error_encodings < 0:
                raise ValueError("Invalid value for `error_encodings`, must be a value greater than or equal to `0`")
            if not isinstance(error_encodings, int):
                raise TypeError("Invalid type for `error_encodings`, type has to be `int`")

        self._error_encodings = error_encodings

    @property
    def encoding_template_name(self):
        # type: () -> string_types
        """Gets the encoding_template_name of this LiveStandbyPoolResponse.

        The name of the encoding template used with this Standby Pool

        :return: The encoding_template_name of this LiveStandbyPoolResponse.
        :rtype: string_types
        """
        return self._encoding_template_name

    @encoding_template_name.setter
    def encoding_template_name(self, encoding_template_name):
        # type: (string_types) -> None
        """Sets the encoding_template_name of this LiveStandbyPoolResponse.

        The name of the encoding template used with this Standby Pool

        :param encoding_template_name: The encoding_template_name of this LiveStandbyPoolResponse.
        :type: string_types
        """

        if encoding_template_name is not None:
            if not isinstance(encoding_template_name, string_types):
                raise TypeError("Invalid type for `encoding_template_name`, type has to be `string_types`")

        self._encoding_template_name = encoding_template_name

    @property
    def pool_status(self):
        # type: () -> LiveStandbyPoolStatus
        """Gets the pool_status of this LiveStandbyPoolResponse.


        :return: The pool_status of this LiveStandbyPoolResponse.
        :rtype: LiveStandbyPoolStatus
        """
        return self._pool_status

    @pool_status.setter
    def pool_status(self, pool_status):
        # type: (LiveStandbyPoolStatus) -> None
        """Sets the pool_status of this LiveStandbyPoolResponse.


        :param pool_status: The pool_status of this LiveStandbyPoolResponse.
        :type: LiveStandbyPoolStatus
        """

        if pool_status is not None:
            if not isinstance(pool_status, LiveStandbyPoolStatus):
                raise TypeError("Invalid type for `pool_status`, type has to be `LiveStandbyPoolStatus`")

        self._pool_status = pool_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(LiveStandbyPoolResponse, self), "to_dict"):
            result = super(LiveStandbyPoolResponse, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.video.video_adaptation_set_list_query_params import VideoAdaptationSetListQueryParams



from bitmovin_api_sdk.encoding.manifests.hls.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.custom_tags.custom_tags_api import CustomTagsApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.iframe.iframe_api import IframeApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.stream_info_list_query_params import StreamInfoListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.azure_speech_services_credentials import AzureSpeechServicesCredentials
from bitmovin_api_sdk.models.azure_speech_to_captions_profanity import AzureSpeechToCaptionsProfanity
import pprint
import six


class AzureSpeechToCaptionsSettings(object):
    @poscheck_model
    def __init__(self,
                 azure_speech_services_credentials=None,
                 region=None,
                 api_endpoint=None,
                 language=None,
                 caption_delay=None,
                 caption_remain_time=None,
                 caption_max_line_length=None,
                 caption_lines=None,
                 profanity_option=None):
        # type: (AzureSpeechServicesCredentials, string_types, string_types, string_types, int, int, int, int, AzureSpeechToCaptionsProfanity) -> None

        self._azure_speech_services_credentials = None
        self._region = None
        self._api_endpoint = None
        self._language = None
        self._caption_delay = None
        self._caption_remain_time = None
        self._caption_max_line_length = None
        self._caption_lines = None
        self._profanity_option = None
        self.discriminator = None

        if azure_speech_services_credentials is not None:
            self.azure_speech_services_credentials = azure_speech_services_credentials
        if region is not None:
            self.region = region
        if api_endpoint is not None:
            self.api_endpoint = api_endpoint
        if language is not None:
            self.language = language
        if caption_delay is not None:
            self.caption_delay = caption_delay
        if caption_remain_time is not None:
            self.caption_remain_time = caption_remain_time
        if caption_max_line_length is not None:
            self.caption_max_line_length = caption_max_line_length
        if caption_lines is not None:
            self.caption_lines = caption_lines
        if profanity_option is not None:
            self.profanity_option = profanity_option

    @property
    def openapi_types(self):
        types = {
            'azure_speech_services_credentials': 'AzureSpeechServicesCredentials',
            'region': 'string_types',
            'api_endpoint': 'string_types',
            'language': 'string_types',
            'caption_delay': 'int',
            'caption_remain_time': 'int',
            'caption_max_line_length': 'int',
            'caption_lines': 'int',
            'profanity_option': 'AzureSpeechToCaptionsProfanity'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'azure_speech_services_credentials': 'azureSpeechServicesCredentials',
            'region': 'region',
            'api_endpoint': 'apiEndpoint',
            'language': 'language',
            'caption_delay': 'captionDelay',
            'caption_remain_time': 'captionRemainTime',
            'caption_max_line_length': 'captionMaxLineLength',
            'caption_lines': 'captionLines',
            'profanity_option': 'profanityOption'
        }
        return attributes

    @property
    def azure_speech_services_credentials(self):
        # type: () -> AzureSpeechServicesCredentials
        """Gets the azure_speech_services_credentials of this AzureSpeechToCaptionsSettings.

        Credential settings to access Azure Speech Services 

        :return: The azure_speech_services_credentials of this AzureSpeechToCaptionsSettings.
        :rtype: AzureSpeechServicesCredentials
        """
        return self._azure_speech_services_credentials

    @azure_speech_services_credentials.setter
    def azure_speech_services_credentials(self, azure_speech_services_credentials):
        # type: (AzureSpeechServicesCredentials) -> None
        """Sets the azure_speech_services_credentials of this AzureSpeechToCaptionsSettings.

        Credential settings to access Azure Speech Services 

        :param azure_speech_services_credentials: The azure_speech_services_credentials of this AzureSpeechToCaptionsSettings.
        :type: AzureSpeechServicesCredentials
        """

        if azure_speech_services_credentials is not None:
            if not isinstance(azure_speech_services_credentials, AzureSpeechServicesCredentials):
                raise TypeError("Invalid type for `azure_speech_services_credentials`, type has to be `AzureSpeechServicesCredentials`")

        self._azure_speech_services_credentials = azure_speech_services_credentials

    @property
    def region(self):
        # type: () -> string_types
        """Gets the region of this AzureSpeechToCaptionsSettings.

        Azure Speech Services Region Identifier. The list of speech service supported regions can be found at Azure's official documentation. 

        :return: The region of this AzureSpeechToCaptionsSettings.
        :rtype: string_types
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (string_types) -> None
        """Sets the region of this AzureSpeechToCaptionsSettings.

        Azure Speech Services Region Identifier. The list of speech service supported regions can be found at Azure's official documentation. 

        :param region: The region of this AzureSpeechToCaptionsSettings.
        :type: string_types
        """

        if region is not None:
            if not isinstance(region, string_types):
                raise TypeError("Invalid type for `region`, type has to be `string_types`")

        self._region = region

    @property
    def api_endpoint(self):
        # type: () -> string_types
        """Gets the api_endpoint of this AzureSpeechToCaptionsSettings.

        Azure Speech Services API endpoint. This information can be found in Azure's Speech resource data. 

        :return: The api_endpoint of this AzureSpeechToCaptionsSettings.
        :rtype: string_types
        """
        return self._api_endpoint

    @api_endpoint.setter
    def api_endpoint(self, api_endpoint):
        # type: (string_types) -> None
        """Sets the api_endpoint of this AzureSpeechToCaptionsSettings.

        Azure Speech Services API endpoint. This information can be found in Azure's Speech resource data. 

        :param api_endpoint: The api_endpoint of this AzureSpeechToCaptionsSettings.
        :type: string_types
        """

        if api_endpoint is not None:
            if not isinstance(api_endpoint, string_types):
                raise TypeError("Invalid type for `api_endpoint`, type has to be `string_types`")

        self._api_endpoint = api_endpoint

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this AzureSpeechToCaptionsSettings.

        Azure Speech to captions supported language (IETF BCP 47 language tag). The list of supported languages can be found at Azure's official documentation. 

        :return: The language of this AzureSpeechToCaptionsSettings.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this AzureSpeechToCaptionsSettings.

        Azure Speech to captions supported language (IETF BCP 47 language tag). The list of supported languages can be found at Azure's official documentation. 

        :param language: The language of this AzureSpeechToCaptionsSettings.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    @property
    def caption_delay(self):
        # type: () -> int
        """Gets the caption_delay of this AzureSpeechToCaptionsSettings.

        How many MILLISECONDS to delay the display of each caption, to mimic a real-time experience. The minimum value is 0. 

        :return: The caption_delay of this AzureSpeechToCaptionsSettings.
        :rtype: int
        """
        return self._caption_delay

    @caption_delay.setter
    def caption_delay(self, caption_delay):
        # type: (int) -> None
        """Sets the caption_delay of this AzureSpeechToCaptionsSettings.

        How many MILLISECONDS to delay the display of each caption, to mimic a real-time experience. The minimum value is 0. 

        :param caption_delay: The caption_delay of this AzureSpeechToCaptionsSettings.
        :type: int
        """

        if caption_delay is not None:
            if not isinstance(caption_delay, int):
                raise TypeError("Invalid type for `caption_delay`, type has to be `int`")

        self._caption_delay = caption_delay

    @property
    def caption_remain_time(self):
        # type: () -> int
        """Gets the caption_remain_time of this AzureSpeechToCaptionsSettings.

        How many MILLISECONDS a caption should remain on screen if it is not replaced by another. The minimum value is 0. 

        :return: The caption_remain_time of this AzureSpeechToCaptionsSettings.
        :rtype: int
        """
        return self._caption_remain_time

    @caption_remain_time.setter
    def caption_remain_time(self, caption_remain_time):
        # type: (int) -> None
        """Sets the caption_remain_time of this AzureSpeechToCaptionsSettings.

        How many MILLISECONDS a caption should remain on screen if it is not replaced by another. The minimum value is 0. 

        :param caption_remain_time: The caption_remain_time of this AzureSpeechToCaptionsSettings.
        :type: int
        """

        if caption_remain_time is not None:
            if not isinstance(caption_remain_time, int):
                raise TypeError("Invalid type for `caption_remain_time`, type has to be `int`")

        self._caption_remain_time = caption_remain_time

    @property
    def caption_max_line_length(self):
        # type: () -> int
        """Gets the caption_max_line_length of this AzureSpeechToCaptionsSettings.

        The maximum number of characters per line for a caption.  The minimum value is 20. 

        :return: The caption_max_line_length of this AzureSpeechToCaptionsSettings.
        :rtype: int
        """
        return self._caption_max_line_length

    @caption_max_line_length.setter
    def caption_max_line_length(self, caption_max_line_length):
        # type: (int) -> None
        """Sets the caption_max_line_length of this AzureSpeechToCaptionsSettings.

        The maximum number of characters per line for a caption.  The minimum value is 20. 

        :param caption_max_line_length: The caption_max_line_length of this AzureSpeechToCaptionsSettings.
        :type: int
        """

        if caption_max_line_length is not None:
            if not isinstance(caption_max_line_length, int):
                raise TypeError("Invalid type for `caption_max_line_length`, type has to be `int`")

        self._caption_max_line_length = caption_max_line_length

    @property
    def caption_lines(self):
        # type: () -> int
        """Gets the caption_lines of this AzureSpeechToCaptionsSettings.

        The number of lines for a caption. The minimum value is 1. 

        :return: The caption_lines of this AzureSpeechToCaptionsSettings.
        :rtype: int
        """
        return self._caption_lines

    @caption_lines.setter
    def caption_lines(self, caption_lines):
        # type: (int) -> None
        """Sets the caption_lines of this AzureSpeechToCaptionsSettings.

        The number of lines for a caption. The minimum value is 1. 

        :param caption_lines: The caption_lines of this AzureSpeechToCaptionsSettings.
        :type: int
        """

        if caption_lines is not None:
            if not isinstance(caption_lines, int):
                raise TypeError("Invalid type for `caption_lines`, type has to be `int`")

        self._caption_lines = caption_lines

    @property
    def profanity_option(self):
        # type: () -> AzureSpeechToCaptionsProfanity
        """Gets the profanity_option of this AzureSpeechToCaptionsSettings.

        The profanity filter options are:  - Masked: Replaces letters in profane words with asterisk (*) characters. - Raw: Include the profane words verbatim. - Removed: Removes profane words. 

        :return: The profanity_option of this AzureSpeechToCaptionsSettings.
        :rtype: AzureSpeechToCaptionsProfanity
        """
        return self._profanity_option

    @profanity_option.setter
    def profanity_option(self, profanity_option):
        # type: (AzureSpeechToCaptionsProfanity) -> None
        """Sets the profanity_option of this AzureSpeechToCaptionsSettings.

        The profanity filter options are:  - Masked: Replaces letters in profane words with asterisk (*) characters. - Raw: Include the profane words verbatim. - Removed: Removes profane words. 

        :param profanity_option: The profanity_option of this AzureSpeechToCaptionsSettings.
        :type: AzureSpeechToCaptionsProfanity
        """

        if profanity_option is not None:
            if not isinstance(profanity_option, AzureSpeechToCaptionsProfanity):
                raise TypeError("Invalid type for `profanity_option`, type has to be `AzureSpeechToCaptionsProfanity`")

        self._profanity_option = profanity_option

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureSpeechToCaptionsSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EncodingTemplateType(Enum):
    VOD = "VOD"
    LIVE = "LIVE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashOnDemandRepresentationType(Enum):
    SEGMENT_BASE = "SEGMENT_BASE"
    SEGMENT_LIST = "SEGMENT_LIST"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_options_entry import LiveOptionsEntry
import pprint
import six


class LiveOptionsSummary(object):
    @poscheck_model
    def __init__(self,
                 hd=None):
        # type: (LiveOptionsEntry) -> None

        self._hd = None
        self.discriminator = None

        if hd is not None:
            self.hd = hd

    @property
    def openapi_types(self):
        types = {
            'hd': 'LiveOptionsEntry'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'hd': 'hd'
        }
        return attributes

    @property
    def hd(self):
        # type: () -> LiveOptionsEntry
        """Gets the hd of this LiveOptionsSummary.


        :return: The hd of this LiveOptionsSummary.
        :rtype: LiveOptionsEntry
        """
        return self._hd

    @hd.setter
    def hd(self, hd):
        # type: (LiveOptionsEntry) -> None
        """Sets the hd of this LiveOptionsSummary.


        :param hd: The hd of this LiveOptionsSummary.
        :type: LiveOptionsEntry
        """

        if hd is not None:
            if not isinstance(hd, LiveOptionsEntry):
                raise TypeError("Invalid type for `hd`, type has to be `LiveOptionsEntry`")

        self._hd = hd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveOptionsSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.organization_type import OrganizationType
from bitmovin_api_sdk.models.signup_source import SignupSource
import pprint
import six


class Organization(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 parent_id=None,
                 label_color=None,
                 limits_per_resource=None,
                 signup_source=None,
                 mfa_required=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, OrganizationType, string_types, string_types, list[ResourceLimitContainer], SignupSource, bool) -> None
        super(Organization, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._type = None
        self._parent_id = None
        self._label_color = None
        self._limits_per_resource = list()
        self._signup_source = None
        self._mfa_required = None
        self.discriminator = None

        if type_ is not None:
            self.type = type_
        if parent_id is not None:
            self.parent_id = parent_id
        if label_color is not None:
            self.label_color = label_color
        if limits_per_resource is not None:
            self.limits_per_resource = limits_per_resource
        if signup_source is not None:
            self.signup_source = signup_source
        if mfa_required is not None:
            self.mfa_required = mfa_required

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Organization, self), 'openapi_types'):
            types = getattr(super(Organization, self), 'openapi_types')

        types.update({
            'type': 'OrganizationType',
            'parent_id': 'string_types',
            'label_color': 'string_types',
            'limits_per_resource': 'list[ResourceLimitContainer]',
            'signup_source': 'SignupSource',
            'mfa_required': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Organization, self), 'attribute_map'):
            attributes = getattr(super(Organization, self), 'attribute_map')

        attributes.update({
            'type': 'type',
            'parent_id': 'parentId',
            'label_color': 'labelColor',
            'limits_per_resource': 'limitsPerResource',
            'signup_source': 'signupSource',
            'mfa_required': 'mfaRequired'
        })
        return attributes

    @property
    def type(self):
        # type: () -> OrganizationType
        """Gets the type of this Organization.

        Specifies the type of the organization in the hierachy. Only sub-organizations can be newly created. (required)

        :return: The type of this Organization.
        :rtype: OrganizationType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (OrganizationType) -> None
        """Sets the type of this Organization.

        Specifies the type of the organization in the hierachy. Only sub-organizations can be newly created. (required)

        :param type_: The type of this Organization.
        :type: OrganizationType
        """

        if type_ is not None:
            if not isinstance(type_, OrganizationType):
                raise TypeError("Invalid type for `type`, type has to be `OrganizationType`")

        self._type = type_

    @property
    def parent_id(self):
        # type: () -> string_types
        """Gets the parent_id of this Organization.

        ID of the parent organization

        :return: The parent_id of this Organization.
        :rtype: string_types
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        # type: (string_types) -> None
        """Sets the parent_id of this Organization.

        ID of the parent organization

        :param parent_id: The parent_id of this Organization.
        :type: string_types
        """

        if parent_id is not None:
            if not isinstance(parent_id, string_types):
                raise TypeError("Invalid type for `parent_id`, type has to be `string_types`")

        self._parent_id = parent_id

    @property
    def label_color(self):
        # type: () -> string_types
        """Gets the label_color of this Organization.

        Hexadecimal color

        :return: The label_color of this Organization.
        :rtype: string_types
        """
        return self._label_color

    @label_color.setter
    def label_color(self, label_color):
        # type: (string_types) -> None
        """Sets the label_color of this Organization.

        Hexadecimal color

        :param label_color: The label_color of this Organization.
        :type: string_types
        """

        if label_color is not None:
            if not isinstance(label_color, string_types):
                raise TypeError("Invalid type for `label_color`, type has to be `string_types`")

        self._label_color = label_color

    @property
    def limits_per_resource(self):
        # type: () -> list[ResourceLimitContainer]
        """Gets the limits_per_resource of this Organization.


        :return: The limits_per_resource of this Organization.
        :rtype: list[ResourceLimitContainer]
        """
        return self._limits_per_resource

    @limits_per_resource.setter
    def limits_per_resource(self, limits_per_resource):
        # type: (list) -> None
        """Sets the limits_per_resource of this Organization.


        :param limits_per_resource: The limits_per_resource of this Organization.
        :type: list[ResourceLimitContainer]
        """

        if limits_per_resource is not None:
            if not isinstance(limits_per_resource, list):
                raise TypeError("Invalid type for `limits_per_resource`, type has to be `list[ResourceLimitContainer]`")

        self._limits_per_resource = limits_per_resource

    @property
    def signup_source(self):
        # type: () -> SignupSource
        """Gets the signup_source of this Organization.

        which platform initiated organisation creation

        :return: The signup_source of this Organization.
        :rtype: SignupSource
        """
        return self._signup_source

    @signup_source.setter
    def signup_source(self, signup_source):
        # type: (SignupSource) -> None
        """Sets the signup_source of this Organization.

        which platform initiated organisation creation

        :param signup_source: The signup_source of this Organization.
        :type: SignupSource
        """

        if signup_source is not None:
            if not isinstance(signup_source, SignupSource):
                raise TypeError("Invalid type for `signup_source`, type has to be `SignupSource`")

        self._signup_source = signup_source

    @property
    def mfa_required(self):
        # type: () -> bool
        """Gets the mfa_required of this Organization.

        Flag indicating if MFA is required for the organization

        :return: The mfa_required of this Organization.
        :rtype: bool
        """
        return self._mfa_required

    @mfa_required.setter
    def mfa_required(self, mfa_required):
        # type: (bool) -> None
        """Sets the mfa_required of this Organization.

        Flag indicating if MFA is required for the organization

        :param mfa_required: The mfa_required of this Organization.
        :type: bool
        """

        if mfa_required is not None:
            if not isinstance(mfa_required, bool):
                raise TypeError("Invalid type for `mfa_required`, type has to be `bool`")

        self._mfa_required = mfa_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Organization, self), "to_dict"):
            result = super(Organization, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Organization):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyVisionTrackSampleEntryName(Enum):
    DVHE = "DVHE"
    DVH1 = "DVH1"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PixelFormatBitDepth(Enum):
    EIGHT_BIT = "EIGHT_BIT"
    TEN_BIT = "TEN_BIT"



from bitmovin_api_sdk.encoding.outputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.outputs.gcs.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.gcs.gcs_output_list_query_params import GcsOutputListQueryParams



from bitmovin_api_sdk.encoding.encodings.muxings.broadcast_ts.broadcast_ts_api import BroadcastTsApi
from bitmovin_api_sdk.encoding.encodings.muxings.broadcast_ts.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.broadcast_ts.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.broadcast_ts.broadcast_ts_muxing_list_query_params import BroadcastTsMuxingListQueryParams



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.image.image_api import ImageApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.image.image_adaptation_set_list_query_params import ImageAdaptationSetListQueryParams



from bitmovin_api_sdk.encoding.templates.templates_api import TemplatesApi
from bitmovin_api_sdk.encoding.templates.encoding_template_response_list_query_params import EncodingTemplateResponseListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.account_api_key import AccountApiKey
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ApiKeysApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ApiKeysApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, **kwargs):
        # type: (dict) -> AccountApiKey
        """Create Api Key

        :return: Api Key
        :rtype: AccountApiKey
        """

        return self.api_client.post(
            '/account/api-keys',
            type=AccountApiKey,
            **kwargs
        )

    def delete(self, api_key_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Api Key

        :param api_key_id: Id of the api key
        :type api_key_id: string_types, required
        :return: Id of the Api Key
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/account/api-keys/{api_key_id}',
            path_params={'api_key_id': api_key_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, api_key_id, **kwargs):
        # type: (string_types, dict) -> AccountApiKey
        """Get Api Key

        :param api_key_id: Id of the api key
        :type api_key_id: string_types, required
        :return: Service specific result
        :rtype: AccountApiKey
        """

        return self.api_client.get(
            '/account/api-keys/{api_key_id}',
            path_params={'api_key_id': api_key_id},
            type=AccountApiKey,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> AccountApiKey
        """List Api Keys

        :return: Api keys
        :rtype: AccountApiKey
        """

        return self.api_client.get(
            '/account/api-keys',
            pagination_response=True,
            type=AccountApiKey,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AwsCloudRegion(Enum):
    US_EAST_1 = "US_EAST_1"
    US_EAST_2 = "US_EAST_2"
    US_WEST_1 = "US_WEST_1"
    US_WEST_2 = "US_WEST_2"
    EU_WEST_1 = "EU_WEST_1"
    EU_CENTRAL_1 = "EU_CENTRAL_1"
    AP_SOUTHEAST_1 = "AP_SOUTHEAST_1"
    AP_SOUTHEAST_2 = "AP_SOUTHEAST_2"
    AP_NORTHEAST_1 = "AP_NORTHEAST_1"
    AP_NORTHEAST_2 = "AP_NORTHEAST_2"
    AP_SOUTH_1 = "AP_SOUTH_1"
    SA_EAST_1 = "SA_EAST_1"
    EU_WEST_2 = "EU_WEST_2"
    EU_WEST_3 = "EU_WEST_3"
    CA_CENTRAL_1 = "CA_CENTRAL_1"
    EU_NORTH_1 = "EU_NORTH_1"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StatisticsResolution(Enum):
    SD = "SD"
    HD = "HD"
    UHD = "UHD"
    UHD_8K = "UHD_8K"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_edition_compatibility import DashEditionCompatibility
from bitmovin_api_sdk.models.dash_iso8601_timestamp_format import DashISO8601TimestampFormat
from bitmovin_api_sdk.models.dash_manifest import DashManifest
from bitmovin_api_sdk.models.dash_manifest_default_version import DashManifestDefaultVersion
from bitmovin_api_sdk.models.dash_profile import DashProfile
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class DashManifestDefault(DashManifest):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None,
                 profile=None,
                 manifest_name=None,
                 namespaces=None,
                 utc_timings=None,
                 dash_edition_compatibility=None,
                 iso8601_timestamp_format=None,
                 encoding_id=None,
                 version=None,
                 periods=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status, DashProfile, string_types, list[XmlNamespace], list[UtcTiming], DashEditionCompatibility, DashISO8601TimestampFormat, string_types, DashManifestDefaultVersion, list[DefaultDashManifestPeriod]) -> None
        super(DashManifestDefault, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, type_=type_, outputs=outputs, status=status, profile=profile, manifest_name=manifest_name, namespaces=namespaces, utc_timings=utc_timings, dash_edition_compatibility=dash_edition_compatibility, iso8601_timestamp_format=iso8601_timestamp_format)

        self._encoding_id = None
        self._version = None
        self._periods = list()
        self.discriminator = None

        if encoding_id is not None:
            self.encoding_id = encoding_id
        if version is not None:
            self.version = version
        if periods is not None:
            self.periods = periods

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DashManifestDefault, self), 'openapi_types'):
            types = getattr(super(DashManifestDefault, self), 'openapi_types')

        types.update({
            'encoding_id': 'string_types',
            'version': 'DashManifestDefaultVersion',
            'periods': 'list[DefaultDashManifestPeriod]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DashManifestDefault, self), 'attribute_map'):
            attributes = getattr(super(DashManifestDefault, self), 'attribute_map')

        attributes.update({
            'encoding_id': 'encodingId',
            'version': 'version',
            'periods': 'periods'
        })
        return attributes

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this DashManifestDefault.

        The id of the encoding to create a default manifest for. Either \"encodingId\" or \"periods\" is required.

        :return: The encoding_id of this DashManifestDefault.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this DashManifestDefault.

        The id of the encoding to create a default manifest for. Either \"encodingId\" or \"periods\" is required.

        :param encoding_id: The encoding_id of this DashManifestDefault.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def version(self):
        # type: () -> DashManifestDefaultVersion
        """Gets the version of this DashManifestDefault.

        Specifies the algorithm that determines which output of the given encoding is included into the manifest. Note that this is not related to the \"manifestGenerator\" version of the \"Start\" request.

        :return: The version of this DashManifestDefault.
        :rtype: DashManifestDefaultVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (DashManifestDefaultVersion) -> None
        """Sets the version of this DashManifestDefault.

        Specifies the algorithm that determines which output of the given encoding is included into the manifest. Note that this is not related to the \"manifestGenerator\" version of the \"Start\" request.

        :param version: The version of this DashManifestDefault.
        :type: DashManifestDefaultVersion
        """

        if version is not None:
            if not isinstance(version, DashManifestDefaultVersion):
                raise TypeError("Invalid type for `version`, type has to be `DashManifestDefaultVersion`")

        self._version = version

    @property
    def periods(self):
        # type: () -> list[DefaultDashManifestPeriod]
        """Gets the periods of this DashManifestDefault.

        Adds a period for every item. Can only be used when setting \"version\" to \"V2\". Either \"periods\" or \"encodingId\" is required.

        :return: The periods of this DashManifestDefault.
        :rtype: list[DefaultDashManifestPeriod]
        """
        return self._periods

    @periods.setter
    def periods(self, periods):
        # type: (list) -> None
        """Sets the periods of this DashManifestDefault.

        Adds a period for every item. Can only be used when setting \"version\" to \"V2\". Either \"periods\" or \"encodingId\" is required.

        :param periods: The periods of this DashManifestDefault.
        :type: list[DefaultDashManifestPeriod]
        """

        if periods is not None:
            if not isinstance(periods, list):
                raise TypeError("Invalid type for `periods`, type has to be `list[DefaultDashManifestPeriod]`")

        self._periods = periods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DashManifestDefault, self), "to_dict"):
            result = super(DashManifestDefault, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashManifestDefault):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.direct_file_upload.direct_file_upload_api import DirectFileUploadApi
from bitmovin_api_sdk.encoding.inputs.direct_file_upload.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.direct_file_upload.direct_file_upload_input_list_query_params import DirectFileUploadInputListQueryParams



from bitmovin_api_sdk.encoding.encodings.streams.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.encodings.streams.filters.stream_filter_list_list_query_params import StreamFilterListListQueryParams



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint


class CodecConfiguration(BitmovinResource):

    discriminator_value_class_map = {
        'AAC': 'AacAudioConfiguration',
        'AUDIO_PASSTHROUGH': 'PassthroughAudioConfiguration',
        'DTS_PASSTHROUGH': 'DtsPassthroughAudioConfiguration',
        'DTS': 'DtsAudioConfiguration',
        'DTSX': 'DtsXAudioConfiguration',
        'DVB_SUBTITLE': 'DvbSubtitleConfiguration',
        'HE_AAC_V1': 'HeAacV1AudioConfiguration',
        'HE_AAC_V2': 'HeAacV2AudioConfiguration',
        'H264': 'H264VideoConfiguration',
        'H265': 'H265VideoConfiguration',
        'VP9': 'Vp9VideoConfiguration',
        'VP8': 'Vp8VideoConfiguration',
        'MP2': 'Mp2AudioConfiguration',
        'MP3': 'Mp3AudioConfiguration',
        'AC3': 'Ac3AudioConfiguration',
        'DD': 'DolbyDigitalAudioConfiguration',
        'EAC3': 'Eac3AudioConfiguration',
        'DDPLUS': 'DolbyDigitalPlusAudioConfiguration',
        'OPUS': 'OpusAudioConfiguration',
        'VORBIS': 'VorbisAudioConfiguration',
        'MJPEG': 'MjpegVideoConfiguration',
        'AV1': 'Av1VideoConfiguration',
        'DOLBY_ATMOS': 'DolbyAtmosAudioConfiguration',
        'H262': 'H262VideoConfiguration',
        'PCM': 'PcmAudioConfiguration',
        'WEBVTT': 'WebVttConfiguration',
        'IMSC': 'ImscConfiguration'
    }

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(CodecConfiguration, self), "to_dict"):
            result = super(CodecConfiguration, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodecConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.streams.bifs.bifs_api import BifsApi
from bitmovin_api_sdk.encoding.encodings.streams.bifs.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.bifs.bif_list_query_params import BifListQueryParams



from bitmovin_api_sdk.encoding.infrastructure.infrastructure_api import InfrastructureApi
from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.infrastructure.gce.gce_api import GceApi
from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_api import AkamaiApi
from bitmovin_api_sdk.encoding.infrastructure.oci.oci_api import OciApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pools_api import PrewarmedEncoderPoolsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
from bitmovin_api_sdk.models.dolby_digital_bitstream_info import DolbyDigitalBitstreamInfo
from bitmovin_api_sdk.models.dolby_digital_channel_layout import DolbyDigitalChannelLayout
from bitmovin_api_sdk.models.dolby_digital_downmixing import DolbyDigitalDownmixing
from bitmovin_api_sdk.models.dolby_digital_evolution_framework_control import DolbyDigitalEvolutionFrameworkControl
from bitmovin_api_sdk.models.dolby_digital_loudness_control import DolbyDigitalLoudnessControl
from bitmovin_api_sdk.models.dolby_digital_preprocessing import DolbyDigitalPreprocessing
import pprint
import six


class DolbyDigitalAudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 bitstream_info=None,
                 channel_layout=None,
                 downmixing=None,
                 evolution_framework_control=None,
                 loudness_control=None,
                 preprocessing=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, DolbyDigitalBitstreamInfo, DolbyDigitalChannelLayout, DolbyDigitalDownmixing, DolbyDigitalEvolutionFrameworkControl, DolbyDigitalLoudnessControl, DolbyDigitalPreprocessing) -> None
        super(DolbyDigitalAudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._bitstream_info = None
        self._channel_layout = None
        self._downmixing = None
        self._evolution_framework_control = None
        self._loudness_control = None
        self._preprocessing = None
        self.discriminator = None

        if bitstream_info is not None:
            self.bitstream_info = bitstream_info
        if channel_layout is not None:
            self.channel_layout = channel_layout
        if downmixing is not None:
            self.downmixing = downmixing
        if evolution_framework_control is not None:
            self.evolution_framework_control = evolution_framework_control
        if loudness_control is not None:
            self.loudness_control = loudness_control
        if preprocessing is not None:
            self.preprocessing = preprocessing

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DolbyDigitalAudioConfiguration, self), 'openapi_types'):
            types = getattr(super(DolbyDigitalAudioConfiguration, self), 'openapi_types')

        types.update({
            'bitstream_info': 'DolbyDigitalBitstreamInfo',
            'channel_layout': 'DolbyDigitalChannelLayout',
            'downmixing': 'DolbyDigitalDownmixing',
            'evolution_framework_control': 'DolbyDigitalEvolutionFrameworkControl',
            'loudness_control': 'DolbyDigitalLoudnessControl',
            'preprocessing': 'DolbyDigitalPreprocessing'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DolbyDigitalAudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(DolbyDigitalAudioConfiguration, self), 'attribute_map')

        attributes.update({
            'bitstream_info': 'bitstreamInfo',
            'channel_layout': 'channelLayout',
            'downmixing': 'downmixing',
            'evolution_framework_control': 'evolutionFrameworkControl',
            'loudness_control': 'loudnessControl',
            'preprocessing': 'preprocessing'
        })
        return attributes

    @property
    def bitstream_info(self):
        # type: () -> DolbyDigitalBitstreamInfo
        """Gets the bitstream_info of this DolbyDigitalAudioConfiguration.

        BitstreamInfo defines metadata parameters contained in the Dolby Digital audio bitstream

        :return: The bitstream_info of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalBitstreamInfo
        """
        return self._bitstream_info

    @bitstream_info.setter
    def bitstream_info(self, bitstream_info):
        # type: (DolbyDigitalBitstreamInfo) -> None
        """Sets the bitstream_info of this DolbyDigitalAudioConfiguration.

        BitstreamInfo defines metadata parameters contained in the Dolby Digital audio bitstream

        :param bitstream_info: The bitstream_info of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalBitstreamInfo
        """

        if bitstream_info is not None:
            if not isinstance(bitstream_info, DolbyDigitalBitstreamInfo):
                raise TypeError("Invalid type for `bitstream_info`, type has to be `DolbyDigitalBitstreamInfo`")

        self._bitstream_info = bitstream_info

    @property
    def channel_layout(self):
        # type: () -> DolbyDigitalChannelLayout
        """Gets the channel_layout of this DolbyDigitalAudioConfiguration.

        Channel layout of the audio codec configuration.

        :return: The channel_layout of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalChannelLayout
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        # type: (DolbyDigitalChannelLayout) -> None
        """Sets the channel_layout of this DolbyDigitalAudioConfiguration.

        Channel layout of the audio codec configuration.

        :param channel_layout: The channel_layout of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalChannelLayout
        """

        if channel_layout is not None:
            if not isinstance(channel_layout, DolbyDigitalChannelLayout):
                raise TypeError("Invalid type for `channel_layout`, type has to be `DolbyDigitalChannelLayout`")

        self._channel_layout = channel_layout

    @property
    def downmixing(self):
        # type: () -> DolbyDigitalDownmixing
        """Gets the downmixing of this DolbyDigitalAudioConfiguration.


        :return: The downmixing of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalDownmixing
        """
        return self._downmixing

    @downmixing.setter
    def downmixing(self, downmixing):
        # type: (DolbyDigitalDownmixing) -> None
        """Sets the downmixing of this DolbyDigitalAudioConfiguration.


        :param downmixing: The downmixing of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalDownmixing
        """

        if downmixing is not None:
            if not isinstance(downmixing, DolbyDigitalDownmixing):
                raise TypeError("Invalid type for `downmixing`, type has to be `DolbyDigitalDownmixing`")

        self._downmixing = downmixing

    @property
    def evolution_framework_control(self):
        # type: () -> DolbyDigitalEvolutionFrameworkControl
        """Gets the evolution_framework_control of this DolbyDigitalAudioConfiguration.

        It provides a framework for signaling new evolution framework applications, such as Intelligent Loudness, in each Dolby codec. 

        :return: The evolution_framework_control of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalEvolutionFrameworkControl
        """
        return self._evolution_framework_control

    @evolution_framework_control.setter
    def evolution_framework_control(self, evolution_framework_control):
        # type: (DolbyDigitalEvolutionFrameworkControl) -> None
        """Sets the evolution_framework_control of this DolbyDigitalAudioConfiguration.

        It provides a framework for signaling new evolution framework applications, such as Intelligent Loudness, in each Dolby codec. 

        :param evolution_framework_control: The evolution_framework_control of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalEvolutionFrameworkControl
        """

        if evolution_framework_control is not None:
            if not isinstance(evolution_framework_control, DolbyDigitalEvolutionFrameworkControl):
                raise TypeError("Invalid type for `evolution_framework_control`, type has to be `DolbyDigitalEvolutionFrameworkControl`")

        self._evolution_framework_control = evolution_framework_control

    @property
    def loudness_control(self):
        # type: () -> DolbyDigitalLoudnessControl
        """Gets the loudness_control of this DolbyDigitalAudioConfiguration.

        Settings for loudness control (required)

        :return: The loudness_control of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalLoudnessControl
        """
        return self._loudness_control

    @loudness_control.setter
    def loudness_control(self, loudness_control):
        # type: (DolbyDigitalLoudnessControl) -> None
        """Sets the loudness_control of this DolbyDigitalAudioConfiguration.

        Settings for loudness control (required)

        :param loudness_control: The loudness_control of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalLoudnessControl
        """

        if loudness_control is not None:
            if not isinstance(loudness_control, DolbyDigitalLoudnessControl):
                raise TypeError("Invalid type for `loudness_control`, type has to be `DolbyDigitalLoudnessControl`")

        self._loudness_control = loudness_control

    @property
    def preprocessing(self):
        # type: () -> DolbyDigitalPreprocessing
        """Gets the preprocessing of this DolbyDigitalAudioConfiguration.


        :return: The preprocessing of this DolbyDigitalAudioConfiguration.
        :rtype: DolbyDigitalPreprocessing
        """
        return self._preprocessing

    @preprocessing.setter
    def preprocessing(self, preprocessing):
        # type: (DolbyDigitalPreprocessing) -> None
        """Sets the preprocessing of this DolbyDigitalAudioConfiguration.


        :param preprocessing: The preprocessing of this DolbyDigitalAudioConfiguration.
        :type: DolbyDigitalPreprocessing
        """

        if preprocessing is not None:
            if not isinstance(preprocessing, DolbyDigitalPreprocessing):
                raise TypeError("Invalid type for `preprocessing`, type has to be `DolbyDigitalPreprocessing`")

        self._preprocessing = preprocessing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DolbyDigitalAudioConfiguration, self), "to_dict"):
            result = super(DolbyDigitalAudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalAudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.filters.ebu_r128_single_pass.ebu_r128_single_pass_api import EbuR128SinglePassApi
from bitmovin_api_sdk.encoding.filters.ebu_r128_single_pass.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.ebu_r128_single_pass.ebu_r128_single_pass_filter_list_query_params import EbuR128SinglePassFilterListQueryParams



from bitmovin_api_sdk.encoding.encodings.input_streams.file.file_api import FileApi
from bitmovin_api_sdk.encoding.encodings.input_streams.file.file_input_stream_list_query_params import FileInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsAttribute(Enum):
    IMPRESSION_ID = "IMPRESSION_ID"
    ACTIVE_PLAYER_STARTUPTIME = "ACTIVE_PLAYER_STARTUPTIME"
    AD = "AD"
    ANALYTICS_VERSION = "ANALYTICS_VERSION"
    AUDIO_BITRATE = "AUDIO_BITRATE"
    AUDIO_CODEC = "AUDIO_CODEC"
    AUTOPLAY = "AUTOPLAY"
    BROWSER = "BROWSER"
    BROWSER_VERSION_MAJOR = "BROWSER_VERSION_MAJOR"
    BROWSER_IS_BOT = "BROWSER_IS_BOT"
    BUFFERED = "BUFFERED"
    CDN_PROVIDER = "CDN_PROVIDER"
    CAST_TECH = "CAST_TECH"
    CITY = "CITY"
    CLIENT_TIME = "CLIENT_TIME"
    COUNTRY = "COUNTRY"
    CUSTOM_DATA_1 = "CUSTOM_DATA_1"
    CUSTOM_DATA_2 = "CUSTOM_DATA_2"
    CUSTOM_DATA_3 = "CUSTOM_DATA_3"
    CUSTOM_DATA_4 = "CUSTOM_DATA_4"
    CUSTOM_DATA_5 = "CUSTOM_DATA_5"
    CUSTOM_DATA_6 = "CUSTOM_DATA_6"
    CUSTOM_DATA_7 = "CUSTOM_DATA_7"
    CUSTOM_DATA_8 = "CUSTOM_DATA_8"
    CUSTOM_DATA_9 = "CUSTOM_DATA_9"
    CUSTOM_DATA_10 = "CUSTOM_DATA_10"
    CUSTOM_DATA_11 = "CUSTOM_DATA_11"
    CUSTOM_DATA_12 = "CUSTOM_DATA_12"
    CUSTOM_DATA_13 = "CUSTOM_DATA_13"
    CUSTOM_DATA_14 = "CUSTOM_DATA_14"
    CUSTOM_DATA_15 = "CUSTOM_DATA_15"
    CUSTOM_DATA_16 = "CUSTOM_DATA_16"
    CUSTOM_DATA_17 = "CUSTOM_DATA_17"
    CUSTOM_DATA_18 = "CUSTOM_DATA_18"
    CUSTOM_DATA_19 = "CUSTOM_DATA_19"
    CUSTOM_DATA_20 = "CUSTOM_DATA_20"
    CUSTOM_DATA_21 = "CUSTOM_DATA_21"
    CUSTOM_DATA_22 = "CUSTOM_DATA_22"
    CUSTOM_DATA_23 = "CUSTOM_DATA_23"
    CUSTOM_DATA_24 = "CUSTOM_DATA_24"
    CUSTOM_DATA_25 = "CUSTOM_DATA_25"
    CUSTOM_DATA_26 = "CUSTOM_DATA_26"
    CUSTOM_DATA_27 = "CUSTOM_DATA_27"
    CUSTOM_DATA_28 = "CUSTOM_DATA_28"
    CUSTOM_DATA_29 = "CUSTOM_DATA_29"
    CUSTOM_DATA_30 = "CUSTOM_DATA_30"
    CUSTOM_DATA_31 = "CUSTOM_DATA_31"
    CUSTOM_DATA_32 = "CUSTOM_DATA_32"
    CUSTOM_DATA_33 = "CUSTOM_DATA_33"
    CUSTOM_DATA_34 = "CUSTOM_DATA_34"
    CUSTOM_DATA_35 = "CUSTOM_DATA_35"
    CUSTOM_DATA_36 = "CUSTOM_DATA_36"
    CUSTOM_DATA_37 = "CUSTOM_DATA_37"
    CUSTOM_DATA_38 = "CUSTOM_DATA_38"
    CUSTOM_DATA_39 = "CUSTOM_DATA_39"
    CUSTOM_DATA_40 = "CUSTOM_DATA_40"
    CUSTOM_DATA_41 = "CUSTOM_DATA_41"
    CUSTOM_DATA_42 = "CUSTOM_DATA_42"
    CUSTOM_DATA_43 = "CUSTOM_DATA_43"
    CUSTOM_DATA_44 = "CUSTOM_DATA_44"
    CUSTOM_DATA_45 = "CUSTOM_DATA_45"
    CUSTOM_DATA_46 = "CUSTOM_DATA_46"
    CUSTOM_DATA_47 = "CUSTOM_DATA_47"
    CUSTOM_DATA_48 = "CUSTOM_DATA_48"
    CUSTOM_DATA_49 = "CUSTOM_DATA_49"
    CUSTOM_DATA_50 = "CUSTOM_DATA_50"
    CUSTOM_USER_ID = "CUSTOM_USER_ID"
    DAY = "DAY"
    DEVICE_CLASS = "DEVICE_CLASS"
    DEVICE_TYPE = "DEVICE_TYPE"
    DOMAIN = "DOMAIN"
    DRM_LOAD_TIME = "DRM_LOAD_TIME"
    DRM_TYPE = "DRM_TYPE"
    DROPPED_FRAMES = "DROPPED_FRAMES"
    DURATION = "DURATION"
    ERROR_CODE = "ERROR_CODE"
    ERROR_MESSAGE = "ERROR_MESSAGE"
    ERROR_RATE = "ERROR_RATE"
    ERROR_PERCENTAGE = "ERROR_PERCENTAGE"
    EXPERIMENT_NAME = "EXPERIMENT_NAME"
    FUNCTION = "FUNCTION"
    HOUR = "HOUR"
    INITIAL_TIME_TO_TARGET_LATENCY = "INITIAL_TIME_TO_TARGET_LATENCY"
    IP_ADDRESS = "IP_ADDRESS"
    IS_CASTING = "IS_CASTING"
    IS_LIVE = "IS_LIVE"
    IS_LOW_LATENCY = "IS_LOW_LATENCY"
    IS_MUTED = "IS_MUTED"
    ISP = "ISP"
    LANGUAGE = "LANGUAGE"
    LATENCY = "LATENCY"
    LICENSE_KEY = "LICENSE_KEY"
    M3U8_URL = "M3U8_URL"
    MINUTE = "MINUTE"
    MONTH = "MONTH"
    MPD_URL = "MPD_URL"
    OPERATINGSYSTEM = "OPERATINGSYSTEM"
    OPERATINGSYSTEM_VERSION_MAJOR = "OPERATINGSYSTEM_VERSION_MAJOR"
    PAGE_LOAD_TIME = "PAGE_LOAD_TIME"
    PAGE_LOAD_TYPE = "PAGE_LOAD_TYPE"
    PATH = "PATH"
    PAUSED = "PAUSED"
    PLATFORM = "PLATFORM"
    PLAY_ATTEMPTS = "PLAY_ATTEMPTS"
    PLAYED = "PLAYED"
    PLAYER = "PLAYER"
    PLAYER_KEY = "PLAYER_KEY"
    PLAYER_STARTUPTIME = "PLAYER_STARTUPTIME"
    PLAYER_TECH = "PLAYER_TECH"
    PLAYER_VERSION = "PLAYER_VERSION"
    PROG_URL = "PROG_URL"
    REBUFFER_PERCENTAGE = "REBUFFER_PERCENTAGE"
    REGION = "REGION"
    SCALE_FACTOR = "SCALE_FACTOR"
    SCREEN_HEIGHT = "SCREEN_HEIGHT"
    SCREEN_WIDTH = "SCREEN_WIDTH"
    SCREEN_ORIENTATION = "SCREEN_ORIENTATION"
    SEEKED = "SEEKED"
    SEQUENCE_NUMBER = "SEQUENCE_NUMBER"
    SIZE = "SIZE"
    STARTUPTIME = "STARTUPTIME"
    STREAM_FORMAT = "STREAM_FORMAT"
    SUPPORTED_VIDEO_CODECS = "SUPPORTED_VIDEO_CODECS"
    TARGET_LATENCY = "TARGET_LATENCY"
    TARGET_LATENCY_DELTA = "TARGET_LATENCY_DELTA"
    TIME = "TIME"
    TIME_TO_TARGET_LATENCY = "TIME_TO_TARGET_LATENCY"
    USER_ID = "USER_ID"
    VIDEO_BITRATE = "VIDEO_BITRATE"
    VIDEO_CODEC = "VIDEO_CODEC"
    VIDEO_DURATION = "VIDEO_DURATION"
    VIDEO_ID = "VIDEO_ID"
    VIDEO_PLAYBACK_HEIGHT = "VIDEO_PLAYBACK_HEIGHT"
    VIDEO_PLAYBACK_WIDTH = "VIDEO_PLAYBACK_WIDTH"
    VIDEO_STARTUPTIME = "VIDEO_STARTUPTIME"
    VIDEO_TITLE = "VIDEO_TITLE"
    VIDEO_WINDOW_HEIGHT = "VIDEO_WINDOW_HEIGHT"
    VIDEO_WINDOW_WIDTH = "VIDEO_WINDOW_WIDTH"
    VIDEOTIME_END = "VIDEOTIME_END"
    VIDEOTIME_START = "VIDEOTIME_START"
    VIDEOSTART_FAILED = "VIDEOSTART_FAILED"
    VIDEOSTART_FAILED_REASON = "VIDEOSTART_FAILED_REASON"
    VIEWTIME = "VIEWTIME"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H264Trellis(Enum):
    DISABLED = "DISABLED"
    ENABLED_FINAL_MB = "ENABLED_FINAL_MB"
    ENABLED_ALL = "ENABLED_ALL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_standby_pool_encoding_status import LiveStandbyPoolEncodingStatus
import pprint
import six


class LiveStandbyPoolEncoding(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 created_at=None,
                 modified_at=None,
                 encoding_id=None,
                 manifests=None,
                 ingest_points=None,
                 status=None):
        # type: (string_types, string_types, string_types, string_types, list[LiveStandbyPoolEncodingManifest], list[LiveStandbyPoolEncodingIngestPoint], LiveStandbyPoolEncodingStatus) -> None

        self._id = None
        self._created_at = None
        self._modified_at = None
        self._encoding_id = None
        self._manifests = list()
        self._ingest_points = list()
        self._status = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if manifests is not None:
            self.manifests = manifests
        if ingest_points is not None:
            self.ingest_points = ingest_points
        if status is not None:
            self.status = status

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'created_at': 'string_types',
            'modified_at': 'string_types',
            'encoding_id': 'string_types',
            'manifests': 'list[LiveStandbyPoolEncodingManifest]',
            'ingest_points': 'list[LiveStandbyPoolEncodingIngestPoint]',
            'status': 'LiveStandbyPoolEncodingStatus'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'created_at': 'createdAt',
            'modified_at': 'modifiedAt',
            'encoding_id': 'encodingId',
            'manifests': 'manifests',
            'ingest_points': 'ingestPoints',
            'status': 'status'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this LiveStandbyPoolEncoding.


        :return: The id of this LiveStandbyPoolEncoding.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this LiveStandbyPoolEncoding.


        :param id_: The id of this LiveStandbyPoolEncoding.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def created_at(self):
        # type: () -> string_types
        """Gets the created_at of this LiveStandbyPoolEncoding.


        :return: The created_at of this LiveStandbyPoolEncoding.
        :rtype: string_types
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (string_types) -> None
        """Sets the created_at of this LiveStandbyPoolEncoding.


        :param created_at: The created_at of this LiveStandbyPoolEncoding.
        :type: string_types
        """

        if created_at is not None:
            if not isinstance(created_at, string_types):
                raise TypeError("Invalid type for `created_at`, type has to be `string_types`")

        self._created_at = created_at

    @property
    def modified_at(self):
        # type: () -> string_types
        """Gets the modified_at of this LiveStandbyPoolEncoding.


        :return: The modified_at of this LiveStandbyPoolEncoding.
        :rtype: string_types
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        # type: (string_types) -> None
        """Sets the modified_at of this LiveStandbyPoolEncoding.


        :param modified_at: The modified_at of this LiveStandbyPoolEncoding.
        :type: string_types
        """

        if modified_at is not None:
            if not isinstance(modified_at, string_types):
                raise TypeError("Invalid type for `modified_at`, type has to be `string_types`")

        self._modified_at = modified_at

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this LiveStandbyPoolEncoding.

        ID of the encoding that ready for ingest in the standby pool

        :return: The encoding_id of this LiveStandbyPoolEncoding.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this LiveStandbyPoolEncoding.

        ID of the encoding that ready for ingest in the standby pool

        :param encoding_id: The encoding_id of this LiveStandbyPoolEncoding.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def manifests(self):
        # type: () -> list[LiveStandbyPoolEncodingManifest]
        """Gets the manifests of this LiveStandbyPoolEncoding.


        :return: The manifests of this LiveStandbyPoolEncoding.
        :rtype: list[LiveStandbyPoolEncodingManifest]
        """
        return self._manifests

    @manifests.setter
    def manifests(self, manifests):
        # type: (list) -> None
        """Sets the manifests of this LiveStandbyPoolEncoding.


        :param manifests: The manifests of this LiveStandbyPoolEncoding.
        :type: list[LiveStandbyPoolEncodingManifest]
        """

        if manifests is not None:
            if not isinstance(manifests, list):
                raise TypeError("Invalid type for `manifests`, type has to be `list[LiveStandbyPoolEncodingManifest]`")

        self._manifests = manifests

    @property
    def ingest_points(self):
        # type: () -> list[LiveStandbyPoolEncodingIngestPoint]
        """Gets the ingest_points of this LiveStandbyPoolEncoding.


        :return: The ingest_points of this LiveStandbyPoolEncoding.
        :rtype: list[LiveStandbyPoolEncodingIngestPoint]
        """
        return self._ingest_points

    @ingest_points.setter
    def ingest_points(self, ingest_points):
        # type: (list) -> None
        """Sets the ingest_points of this LiveStandbyPoolEncoding.


        :param ingest_points: The ingest_points of this LiveStandbyPoolEncoding.
        :type: list[LiveStandbyPoolEncodingIngestPoint]
        """

        if ingest_points is not None:
            if not isinstance(ingest_points, list):
                raise TypeError("Invalid type for `ingest_points`, type has to be `list[LiveStandbyPoolEncodingIngestPoint]`")

        self._ingest_points = ingest_points

    @property
    def status(self):
        # type: () -> LiveStandbyPoolEncodingStatus
        """Gets the status of this LiveStandbyPoolEncoding.


        :return: The status of this LiveStandbyPoolEncoding.
        :rtype: LiveStandbyPoolEncodingStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (LiveStandbyPoolEncodingStatus) -> None
        """Sets the status of this LiveStandbyPoolEncoding.


        :param status: The status of this LiveStandbyPoolEncoding.
        :type: LiveStandbyPoolEncodingStatus
        """

        if status is not None:
            if not isinstance(status, LiveStandbyPoolEncodingStatus):
                raise TypeError("Invalid type for `status`, type has to be `LiveStandbyPoolEncodingStatus`")

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolEncoding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_representation import AutoRepresentation
from bitmovin_api_sdk.models.per_title_fixed_resolution_and_bitrate_configuration import PerTitleFixedResolutionAndBitrateConfiguration
import pprint
import six


class PerTitleConfiguration(object):
    @poscheck_model
    def __init__(self,
                 min_bitrate=None,
                 max_bitrate=None,
                 min_bitrate_step_size=None,
                 max_bitrate_step_size=None,
                 auto_representations=None,
                 complexity_factor=None,
                 fixed_resolution_and_bitrate_configuration=None,
                 resolution_scale_factor=None):
        # type: (int, int, float, float, AutoRepresentation, float, PerTitleFixedResolutionAndBitrateConfiguration, float) -> None

        self._min_bitrate = None
        self._max_bitrate = None
        self._min_bitrate_step_size = None
        self._max_bitrate_step_size = None
        self._auto_representations = None
        self._complexity_factor = None
        self._fixed_resolution_and_bitrate_configuration = None
        self._resolution_scale_factor = None
        self.discriminator = None

        if min_bitrate is not None:
            self.min_bitrate = min_bitrate
        if max_bitrate is not None:
            self.max_bitrate = max_bitrate
        if min_bitrate_step_size is not None:
            self.min_bitrate_step_size = min_bitrate_step_size
        if max_bitrate_step_size is not None:
            self.max_bitrate_step_size = max_bitrate_step_size
        if auto_representations is not None:
            self.auto_representations = auto_representations
        if complexity_factor is not None:
            self.complexity_factor = complexity_factor
        if fixed_resolution_and_bitrate_configuration is not None:
            self.fixed_resolution_and_bitrate_configuration = fixed_resolution_and_bitrate_configuration
        if resolution_scale_factor is not None:
            self.resolution_scale_factor = resolution_scale_factor

    @property
    def openapi_types(self):
        types = {
            'min_bitrate': 'int',
            'max_bitrate': 'int',
            'min_bitrate_step_size': 'float',
            'max_bitrate_step_size': 'float',
            'auto_representations': 'AutoRepresentation',
            'complexity_factor': 'float',
            'fixed_resolution_and_bitrate_configuration': 'PerTitleFixedResolutionAndBitrateConfiguration',
            'resolution_scale_factor': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'min_bitrate': 'minBitrate',
            'max_bitrate': 'maxBitrate',
            'min_bitrate_step_size': 'minBitrateStepSize',
            'max_bitrate_step_size': 'maxBitrateStepSize',
            'auto_representations': 'autoRepresentations',
            'complexity_factor': 'complexityFactor',
            'fixed_resolution_and_bitrate_configuration': 'fixedResolutionAndBitrateConfiguration',
            'resolution_scale_factor': 'resolutionScaleFactor'
        }
        return attributes

    @property
    def min_bitrate(self):
        # type: () -> int
        """Gets the min_bitrate of this PerTitleConfiguration.

        The minimum bitrate that will be used by the Per-Title algorithm.

        :return: The min_bitrate of this PerTitleConfiguration.
        :rtype: int
        """
        return self._min_bitrate

    @min_bitrate.setter
    def min_bitrate(self, min_bitrate):
        # type: (int) -> None
        """Sets the min_bitrate of this PerTitleConfiguration.

        The minimum bitrate that will be used by the Per-Title algorithm.

        :param min_bitrate: The min_bitrate of this PerTitleConfiguration.
        :type: int
        """

        if min_bitrate is not None:
            if not isinstance(min_bitrate, int):
                raise TypeError("Invalid type for `min_bitrate`, type has to be `int`")

        self._min_bitrate = min_bitrate

    @property
    def max_bitrate(self):
        # type: () -> int
        """Gets the max_bitrate of this PerTitleConfiguration.

        The maximum bitrate that will be used by the Per-Title algorithm. It will not generate any rendition with a higher bitrate.

        :return: The max_bitrate of this PerTitleConfiguration.
        :rtype: int
        """
        return self._max_bitrate

    @max_bitrate.setter
    def max_bitrate(self, max_bitrate):
        # type: (int) -> None
        """Sets the max_bitrate of this PerTitleConfiguration.

        The maximum bitrate that will be used by the Per-Title algorithm. It will not generate any rendition with a higher bitrate.

        :param max_bitrate: The max_bitrate of this PerTitleConfiguration.
        :type: int
        """

        if max_bitrate is not None:
            if not isinstance(max_bitrate, int):
                raise TypeError("Invalid type for `max_bitrate`, type has to be `int`")

        self._max_bitrate = max_bitrate

    @property
    def min_bitrate_step_size(self):
        # type: () -> float
        """Gets the min_bitrate_step_size of this PerTitleConfiguration.

        The minimum ratio between the bitrates of generated renditions, e.g. if the first bitrate is 240,000, a minimum ratio of 1.5 will require the next higher bitrate to be at least 360,000

        :return: The min_bitrate_step_size of this PerTitleConfiguration.
        :rtype: float
        """
        return self._min_bitrate_step_size

    @min_bitrate_step_size.setter
    def min_bitrate_step_size(self, min_bitrate_step_size):
        # type: (float) -> None
        """Sets the min_bitrate_step_size of this PerTitleConfiguration.

        The minimum ratio between the bitrates of generated renditions, e.g. if the first bitrate is 240,000, a minimum ratio of 1.5 will require the next higher bitrate to be at least 360,000

        :param min_bitrate_step_size: The min_bitrate_step_size of this PerTitleConfiguration.
        :type: float
        """

        if min_bitrate_step_size is not None:
            if not isinstance(min_bitrate_step_size, (float, int)):
                raise TypeError("Invalid type for `min_bitrate_step_size`, type has to be `float`")

        self._min_bitrate_step_size = min_bitrate_step_size

    @property
    def max_bitrate_step_size(self):
        # type: () -> float
        """Gets the max_bitrate_step_size of this PerTitleConfiguration.

        The maximum ratio between the bitrates of neighbouring renditions, e.g., if the first bitrate is 240,000, a maximum ratio of 1.9 will require the next higher bitrate to be at most 456,000

        :return: The max_bitrate_step_size of this PerTitleConfiguration.
        :rtype: float
        """
        return self._max_bitrate_step_size

    @max_bitrate_step_size.setter
    def max_bitrate_step_size(self, max_bitrate_step_size):
        # type: (float) -> None
        """Sets the max_bitrate_step_size of this PerTitleConfiguration.

        The maximum ratio between the bitrates of neighbouring renditions, e.g., if the first bitrate is 240,000, a maximum ratio of 1.9 will require the next higher bitrate to be at most 456,000

        :param max_bitrate_step_size: The max_bitrate_step_size of this PerTitleConfiguration.
        :type: float
        """

        if max_bitrate_step_size is not None:
            if not isinstance(max_bitrate_step_size, (float, int)):
                raise TypeError("Invalid type for `max_bitrate_step_size`, type has to be `float`")

        self._max_bitrate_step_size = max_bitrate_step_size

    @property
    def auto_representations(self):
        # type: () -> AutoRepresentation
        """Gets the auto_representations of this PerTitleConfiguration.


        :return: The auto_representations of this PerTitleConfiguration.
        :rtype: AutoRepresentation
        """
        return self._auto_representations

    @auto_representations.setter
    def auto_representations(self, auto_representations):
        # type: (AutoRepresentation) -> None
        """Sets the auto_representations of this PerTitleConfiguration.


        :param auto_representations: The auto_representations of this PerTitleConfiguration.
        :type: AutoRepresentation
        """

        if auto_representations is not None:
            if not isinstance(auto_representations, AutoRepresentation):
                raise TypeError("Invalid type for `auto_representations`, type has to be `AutoRepresentation`")

        self._auto_representations = auto_representations

    @property
    def complexity_factor(self):
        # type: () -> float
        """Gets the complexity_factor of this PerTitleConfiguration.

        Will modify the assumed complexity for the Per-Title algorithm (> 0.0). Values higher than 1 will increase complexity and thus select smaller resolutions for given bitrates. This will also result in a higher bitrate for the top rendition. Values lower than 1 will decrease assumed complexity and thus select higher resolutions for given bitrates and also decrease the bitrate of the top rendition

        :return: The complexity_factor of this PerTitleConfiguration.
        :rtype: float
        """
        return self._complexity_factor

    @complexity_factor.setter
    def complexity_factor(self, complexity_factor):
        # type: (float) -> None
        """Sets the complexity_factor of this PerTitleConfiguration.

        Will modify the assumed complexity for the Per-Title algorithm (> 0.0). Values higher than 1 will increase complexity and thus select smaller resolutions for given bitrates. This will also result in a higher bitrate for the top rendition. Values lower than 1 will decrease assumed complexity and thus select higher resolutions for given bitrates and also decrease the bitrate of the top rendition

        :param complexity_factor: The complexity_factor of this PerTitleConfiguration.
        :type: float
        """

        if complexity_factor is not None:
            if complexity_factor is not None and complexity_factor <= 0:
                raise ValueError("Invalid value for `complexity_factor`, must be a value greater than `0`")
            if not isinstance(complexity_factor, (float, int)):
                raise TypeError("Invalid type for `complexity_factor`, type has to be `float`")

        self._complexity_factor = complexity_factor

    @property
    def fixed_resolution_and_bitrate_configuration(self):
        # type: () -> PerTitleFixedResolutionAndBitrateConfiguration
        """Gets the fixed_resolution_and_bitrate_configuration of this PerTitleConfiguration.

        Additional configuration for fixed resolution and bitrate templates

        :return: The fixed_resolution_and_bitrate_configuration of this PerTitleConfiguration.
        :rtype: PerTitleFixedResolutionAndBitrateConfiguration
        """
        return self._fixed_resolution_and_bitrate_configuration

    @fixed_resolution_and_bitrate_configuration.setter
    def fixed_resolution_and_bitrate_configuration(self, fixed_resolution_and_bitrate_configuration):
        # type: (PerTitleFixedResolutionAndBitrateConfiguration) -> None
        """Sets the fixed_resolution_and_bitrate_configuration of this PerTitleConfiguration.

        Additional configuration for fixed resolution and bitrate templates

        :param fixed_resolution_and_bitrate_configuration: The fixed_resolution_and_bitrate_configuration of this PerTitleConfiguration.
        :type: PerTitleFixedResolutionAndBitrateConfiguration
        """

        if fixed_resolution_and_bitrate_configuration is not None:
            if not isinstance(fixed_resolution_and_bitrate_configuration, PerTitleFixedResolutionAndBitrateConfiguration):
                raise TypeError("Invalid type for `fixed_resolution_and_bitrate_configuration`, type has to be `PerTitleFixedResolutionAndBitrateConfiguration`")

        self._fixed_resolution_and_bitrate_configuration = fixed_resolution_and_bitrate_configuration

    @property
    def resolution_scale_factor(self):
        # type: () -> float
        """Gets the resolution_scale_factor of this PerTitleConfiguration.

        This factor influences the resolution selection of the per-title algorithm. The default value is 0.0. negative values will lead to results where the algorithm will choose lower resolutions for given bitrates. A positive value will result in higher resolutions to be selected. The range of the factor is -5.0 to +5.0. Please note that changing this factor might also lead to slightly different bitrate selection by the algorithm.

        :return: The resolution_scale_factor of this PerTitleConfiguration.
        :rtype: float
        """
        return self._resolution_scale_factor

    @resolution_scale_factor.setter
    def resolution_scale_factor(self, resolution_scale_factor):
        # type: (float) -> None
        """Sets the resolution_scale_factor of this PerTitleConfiguration.

        This factor influences the resolution selection of the per-title algorithm. The default value is 0.0. negative values will lead to results where the algorithm will choose lower resolutions for given bitrates. A positive value will result in higher resolutions to be selected. The range of the factor is -5.0 to +5.0. Please note that changing this factor might also lead to slightly different bitrate selection by the algorithm.

        :param resolution_scale_factor: The resolution_scale_factor of this PerTitleConfiguration.
        :type: float
        """

        if resolution_scale_factor is not None:
            if not isinstance(resolution_scale_factor, (float, int)):
                raise TypeError("Invalid type for `resolution_scale_factor`, type has to be `float`")

        self._resolution_scale_factor = resolution_scale_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerTitleConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DrmType(Enum):
    WIDEVINE = "WIDEVINE"
    PLAYREADY = "PLAYREADY"
    PRIMETIME = "PRIMETIME"
    FAIRPLAY = "FAIRPLAY"
    MARLIN = "MARLIN"
    CLEARKEY = "CLEARKEY"
    AES = "AES"
    CENC = "CENC"
    SPEKE = "SPEKE"



from bitmovin_api_sdk.encoding.configurations.audio.aac.aac_api import AacApi
from bitmovin_api_sdk.encoding.configurations.audio.aac.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.aac.aac_audio_configuration_list_query_params import AacAudioConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.s3_output import S3Output
from bitmovin_api_sdk.encoding.outputs.s3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.s3.s3_output_list_query_params import S3OutputListQueryParams


class S3Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(S3Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, s3_output, **kwargs):
        # type: (S3Output, dict) -> S3Output
        """Create S3 Output

        :param s3_output: The S3 output to be created  The following permissions are required for S3 output:  * s3:PutObject  * s3:PutObjectAcl  * s3:ListBucket  * s3:GetBucketLocation 
        :type s3_output: S3Output, required
        :return: S3 output
        :rtype: S3Output
        """

        return self.api_client.post(
            '/encoding/outputs/s3',
            s3_output,
            type=S3Output,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> S3Output
        """Delete S3 Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the input
        :rtype: S3Output
        """

        return self.api_client.delete(
            '/encoding/outputs/s3/{output_id}',
            path_params={'output_id': output_id},
            type=S3Output,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> S3Output
        """S3 Output Details

        :param output_id: Id of the input
        :type output_id: string_types, required
        :return: S3 output
        :rtype: S3Output
        """

        return self.api_client.get(
            '/encoding/outputs/s3/{output_id}',
            path_params={'output_id': output_id},
            type=S3Output,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (S3OutputListQueryParams, dict) -> S3Output
        """List S3 Outputs

        :param query_params: Query parameters
        :type query_params: S3OutputListQueryParams
        :return: List of S3 outputs
        :rtype: S3Output
        """

        return self.api_client.get(
            '/encoding/outputs/s3',
            query_params=query_params,
            pagination_response=True,
            type=S3Output,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.input_streams.ingest.ingest_api import IngestApi
from bitmovin_api_sdk.encoding.encodings.input_streams.ingest.ingest_input_stream_list_query_params import IngestInputStreamListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.configurations.audio.aac.aac_api import AacApi
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.dts_passthrough_api import DtsPassthroughApi
from bitmovin_api_sdk.encoding.configurations.audio.dts.dts_api import DtsApi
from bitmovin_api_sdk.encoding.configurations.audio.dtsx.dtsx_api import DtsxApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v1.he_aac_v1_api import HeAacV1Api
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v2.he_aac_v2_api import HeAacV2Api
from bitmovin_api_sdk.encoding.configurations.audio.passthrough.passthrough_api import PassthroughApi
from bitmovin_api_sdk.encoding.configurations.audio.vorbis.vorbis_api import VorbisApi
from bitmovin_api_sdk.encoding.configurations.audio.opus.opus_api import OpusApi
from bitmovin_api_sdk.encoding.configurations.audio.pcm.pcm_api import PcmApi
from bitmovin_api_sdk.encoding.configurations.audio.ac3.ac3_api import Ac3Api
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital.dolby_digital_api import DolbyDigitalApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital_plus.dolby_digital_plus_api import DolbyDigitalPlusApi
from bitmovin_api_sdk.encoding.configurations.audio.eac3.eac3_api import Eac3Api
from bitmovin_api_sdk.encoding.configurations.audio.mp2.mp2_api import Mp2Api
from bitmovin_api_sdk.encoding.configurations.audio.mp3.mp3_api import Mp3Api


class AudioApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AudioApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.aac = AacApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dts_passthrough = DtsPassthroughApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dts = DtsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dtsx = DtsxApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dolby_atmos = DolbyAtmosApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.he_aac_v1 = HeAacV1Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.he_aac_v2 = HeAacV2Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.passthrough = PassthroughApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vorbis = VorbisApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.opus = OpusApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.pcm = PcmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ac3 = Ac3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dolby_digital = DolbyDigitalApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dolby_digital_plus = DolbyDigitalPlusApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.eac3 = Eac3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp2 = Mp2Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp3 = Mp3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.sidecar_file import SidecarFile
from bitmovin_api_sdk.encoding.encodings.sidecars.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.sidecars.webvtt.webvtt_api import WebvttApi
from bitmovin_api_sdk.encoding.encodings.sidecars.sidecar_file_list_query_params import SidecarFileListQueryParams


class SidecarsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SidecarsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.webvtt = WebvttApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, sidecar_file, **kwargs):
        # type: (string_types, SidecarFile, dict) -> SidecarFile
        """Add Sidecar

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param sidecar_file: The Sidecar to be added
        :type sidecar_file: SidecarFile, required
        :return: Sidecar
        :rtype: SidecarFile
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/sidecars',
            sidecar_file,
            path_params={'encoding_id': encoding_id},
            type=SidecarFile,
            **kwargs
        )

    def delete(self, encoding_id, sidecar_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Sidecar

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param sidecar_id: Id of the sidecar.
        :type sidecar_id: string_types, required
        :return: Id of the sidecar
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/sidecars/{sidecar_id}',
            path_params={'encoding_id': encoding_id, 'sidecar_id': sidecar_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, sidecar_id, **kwargs):
        # type: (string_types, string_types, dict) -> SidecarFile
        """Sidecar Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param sidecar_id: Id of the sidecar.
        :type sidecar_id: string_types, required
        :return: Subtitle
        :rtype: SidecarFile
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/sidecars/{sidecar_id}',
            path_params={'encoding_id': encoding_id, 'sidecar_id': sidecar_id},
            type=SidecarFile,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, SidecarFileListQueryParams, dict) -> SidecarFile
        """List Sidecars

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SidecarFileListQueryParams
        :return: List of subtitles
        :rtype: SidecarFile
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/sidecars',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=SidecarFile,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StaticIpStatus(Enum):
    CREATING = "CREATING"
    UNUSED = "UNUSED"
    ERROR = "ERROR"
    USED = "USED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Av1PresetConfiguration(Enum):
    VOD_QUALITY = "VOD_QUALITY"
    VOD_STANDARD = "VOD_STANDARD"
    VOD_SPEED = "VOD_SPEED"
